Constants
*********

Enable Flags
------------

.. currentmodule:: ModernGL

.. autodata:: BLEND
.. autodata:: DEPTH_TEST
.. autodata:: CULL_FACE
.. autodata:: MULTISAMPLE

Versions
--------

.. currentmodule:: ModernGL

.. autoclass:: Version

.. autodata:: CORE_330
.. autodata:: CORE_400
.. autodata:: CORE_410
.. autodata:: CORE_420
.. autodata:: CORE_430
.. autodata:: CORE_440
.. autodata:: CORE_450

Primitives
----------

.. currentmodule:: ModernGL

.. autoclass:: Primitive

.. autodata:: TRIANGLES
.. autodata:: TRIANGLE_STRIP
.. autodata:: TRIANGLE_FAN
.. autodata:: LINES
.. autodata:: LINE_STRIP
.. autodata:: LINE_LOOP
.. autodata:: POINTS
.. autodata:: LINE_STRIP_ADJACENCY
.. autodata:: LINES_ADJACENCY
.. autodata:: TRIANGLE_STRIP_ADJACENCY
.. autodata:: TRIANGLES_ADJACENCY

.. toctree::
	:maxdepth: 4
